@@ -6,15 +6,14 @@
  * Copyright (C) 2022, Sergey Kasmynin (https://github.com/SergeyKasmy)
  */
 
-mod config;
+pub mod config;
 mod data;
-mod last_read_id;
+mod read_filter;
 
-pub use self::config::config;
 pub use self::data::{
 	generate_google_oauth2, generate_google_password, generate_telegram, generate_twitter_auth,
 	google_oauth2, google_password, telegram, twitter,
 };
-pub use self::last_read_id::{last_read_id, save_last_read_id};
+pub use self::read_filter::{read_filter, save_read_filter};
 
 const PREFIX: &str = "fetcher";
