@@ -6,17 +6,15 @@
  * Copyright (C) 2022, Sergey Kasmynin (https://github.com/SergeyKasmy)
  */
 
-mod message;
+pub mod message;
 mod telegram;
 
 pub use message::{Media, Message};
-use serde::Deserialize;
 pub use telegram::Telegram;
 
 use crate::error::Result;
 
-#[derive(Deserialize, Debug)]
-#[serde(tag = "type", rename_all = "snake_case", deny_unknown_fields)]
+#[derive(Debug)]
 pub enum Sink {
 	Telegram(Telegram),
 }
